<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

require( HTBUILDER_PL_PATH . 'includes/admin/classes/class.settings-api.php' );

class HTBuilder_Admin_Settings_Pro {

    private $settings_api;

    function __construct() {
        $this->settings_api = new HTBuilder_Settings_API();
        add_action( 'admin_init', array( $this, 'admin_init' ) );
        add_action( 'admin_menu', array( $this, 'admin_menu' ), 220 );
        add_action('admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );
        add_action( 'wsa_form_bottom_htbuilder_general_tabs', array( $this, 'html_general_tabs' ) );
        add_action( 'wsa_form_top_htbuilder_element_tabs', array( $this, 'html_element_toogle_button' ) );
        add_action( 'wsa_form_top_htbuilder_element_tabs', array( $this, 'html_popup_box' ) );
        add_action( 'wsa_form_bottom_htbuilder_plugins_tabs', [ $this, 'html_our_plugins_library_tabs' ] );
        add_action( 'wsa_form_bottom_htbuilder_template_tabs', [ $this, 'html_template_library_tabs' ] );
    }

    // Admin Initialize
    function admin_init() {

        //set the settings
        $this->settings_api->set_sections( $this->admin_get_settings_sections() );
        $this->settings_api->set_fields( $this->admin_fields_settings() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    // Plugins menu Register
    function admin_menu() {
        add_menu_page( 
            __( 'HT Builder', 'ht-builder-pro' ),
            __( 'HT Builder', 'ht-builder-pro' ),
            'manage_options',
            'htbuilder',
            array ( $this, 'plugin_page' ),
            'dashicons-text-page',
            100
        );
    }

    // Admin Scripts
    public function enqueue_admin_scripts(){

        wp_enqueue_style( 'htbuilder-admin', HTBUILDER_PL_URL . 'includes/admin/assets/css/admin_optionspanel.css', FALSE, HTBUILDER_VERSION );
        
        wp_enqueue_script( 'htbuilder-admin', HTBUILDER_PL_URL . 'includes/admin/assets/js/admin_scripts.js', array('jquery'), HTBUILDER_VERSION, TRUE );
    }

    // Options page Section register
    function admin_get_settings_sections() {
        $sections = array(
            
            array(
                'id'    => 'htbuilder_general_tabs',
                'title' => esc_html__( 'General', 'ht-builder-pro' )
            ),

            array(
                'id'    => 'htbuilder_templatebuilder_tabs',
                'title' => esc_html__( 'Template Builder', 'ht-builder-pro' )
            ),

            array(
                'id'    => 'htbuilder_element_tabs',
                'title' => esc_html__( 'Elements', 'ht-builder-pro' )
            ),

             array(
                'id'    => 'htbuilder_template_tabs',
                'title' => esc_html__( 'Template', 'ht-builder-pro' )
            ),

            array(
                'id'    => 'htbuilder_plugins_tabs',
                'title' => esc_html__( 'Our Plugins', 'ht-builder-pro' )
            ),

        );
        return $sections;
    }

    // Options page field register
    protected function admin_fields_settings() {

        $settings_fields = array(

            'htbuilder_general_tabs' => array(),
            
            'htbuilder_templatebuilder_tabs' => array(

                array(
                    'name'  => 'enablecustomtemplate',
                    'label'  => __( 'Enable Custom template Layout', 'ht-builder-pro' ),
                    'desc'  => __( 'Enable', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'    => 'single_blog_page',
                    'label'   => __( 'Single Blog Template.', 'ht-builder-pro' ),
                    'desc'    => __( 'You can select Single blog page from here.', 'ht-builder-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htbuilder_elementor_template()
                ),

                array(
                    'name'    => 'archive_blog_page',
                    'label'   => __( 'Blog Template.', 'ht-builder-pro' ),
                    'desc'    => __( 'You can select blog page from here.', 'ht-builder-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htbuilder_elementor_template()
                ),

                array(
                    'name'    => 'header_page',
                    'label'   => __( 'Header Template.', 'ht-builder-pro' ),
                    'desc'    => __( 'You can select header template from here.', 'ht-builder-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htbuilder_elementor_template()
                ),

                array(
                    'name'    => 'footer_page',
                    'label'   => __( 'Footer Template.', 'ht-builder-pro' ),
                    'desc'    => __( 'You can select footer template from here.', 'ht-builder-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htbuilder_elementor_template()
                ),

                array(
                    'name'    => 'search_page',
                    'label'   => __( 'Search Page Template.', 'ht-builder-pro' ),
                    'desc'    => __( 'You can select search page from here.', 'ht-builder-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htbuilder_elementor_template(),
                    'class'   =>'htproelement',
                ),

                array(
                    'name'    => 'error_page',
                    'label'   => __( '404 Page Template.', 'ht-builder-pro' ),
                    'desc'    => __( 'You can select 404 page from here.', 'ht-builder-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htbuilder_elementor_template(),
                    'class'   =>'htproelement',
                ),

                array(
                    'name'    => 'coming_soon_page',
                    'label'   => __( 'Coming Soon Page Template.', 'ht-builder-pro' ),
                    'desc'    => __( 'You can select coming soon page from here.', 'ht-builder-pro' ),
                    'type'    => 'select',
                    'default' => '0',
                    'options' => htbuilder_elementor_template(),
                    'class'   =>'htproelement',
                ),

            ),

            'htbuilder_element_tabs'=>array(

                array(
                    'name'  => 'bl_post_title',
                    'label'  => __( 'Post Title', 'ht-builder-pro' ),
                    'desc'  => __( 'Post Title', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_featured_image',
                    'label'  => __( 'Post Featured Image', 'ht-builder-pro' ),
                    'desc'  => __( 'Post Featured Image', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_meta_info',
                    'label'  => __( 'Post Meta Info', 'ht-builder-pro' ),
                    'desc'  => __( 'Post Meta Info', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_excerpt',
                    'label'  => __( 'Post Excerpt', 'ht-builder-pro' ),
                    'desc'  => __( 'Post Excerpt', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_content',
                    'label'  => __( 'Post Content', 'ht-builder-pro' ),
                    'desc'  => __( 'Post Content', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_comments',
                    'label'  => __( 'Post Comments', 'ht-builder-pro' ),
                    'desc'  => __( 'Post Comments', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_search_form',
                    'label'  => __( 'Post Search Form', 'ht-builder-pro' ),
                    'desc'  => __( 'Post Search Form', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_archive',
                    'label'  => __( 'Archive Posts', 'ht-builder-pro' ),
                    'desc'  => __( 'Archive Posts', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_archive_title',
                    'label'  => __( 'Archive Title', 'ht-builder-pro' ),
                    'desc'  => __( 'Archive Title', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),
                
                array(
                    'name'  => 'bl_page_title',
                    'label'  => __( 'Page Title', 'ht-builder-pro' ),
                    'desc'  => __( 'Page Title', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_site_title',
                    'label'  => __( 'Site Title', 'ht-builder-pro' ),
                    'desc'  => __( 'Site Title', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_site_logo',
                    'label'  => __( 'Site Logo', 'ht-builder-pro' ),
                    'desc'  => __( 'Site Logo', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_nav_menu',
                    'label'  => __( 'Nav Menu', 'ht-builder-pro' ),
                    'desc'  => __( 'Nav Menu', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_author_info',
                    'label'  => __( 'Author Info', 'ht-builder-pro' ),
                    'desc'  => __( 'Author Info', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_social_share',
                    'label'  => __( 'Social Share', 'ht-builder-pro' ),
                    'desc'  => __( 'Social share', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_print_page',
                    'label'  => __( 'Print Page', 'ht-builder-pro' ),
                    'desc'  => __( 'Print Page', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_view_counter',
                    'label'  => __( 'View Counter', 'ht-builder-pro' ),
                    'desc'  => __( 'View Counter', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_post_navigation',
                    'label'  => __( 'Post Navigation', 'ht-builder-pro' ),
                    'desc'  => __( 'Post Navigation', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_related_post',
                    'label'  => __( 'Related Post', 'ht-builder-pro' ),
                    'desc'  => __( 'Related Post', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),

                array(
                    'name'  => 'bl_popular_post',
                    'label'  => __( 'Popular Post', 'ht-builder-pro' ),
                    'desc'  => __( 'Popular Post', 'ht-builder-pro' ),
                    'type'  => 'checkbox',
                    'default' => 'on',
                    'class'=>'htbuilder_table_row',
                ),


            ),

            'htbuilder_plugins_tabs' => array(),

        );
        
        return array_merge( $settings_fields );
    }

    // Admin Menu Page Render
    function plugin_page() {

        echo '<div class="wrap">';
            echo '<h2>'.esc_html__( 'HT Builder Settings','ht-builder-pro' ).'</h2>';
            $this->save_message();
            $this->settings_api->show_navigation();
            $this->settings_api->show_forms();
        echo '</div>';

    }

    // Save Options Message
    function save_message() {
        if( isset($_GET['settings-updated']) ) { ?>
            <div class="updated notice is-dismissible"> 
                <p><strong><?php esc_html_e('Successfully Settings Saved.', 'ht-builder-pro') ?></strong></p>
            </div>
            <?php
        }
    }

    // Pop up Box
    function html_popup_box(){
        ob_start();
        ?>
            <script type="text/javascript">
                ( function( $ ) {
                    $(function() {
                        $(".htbuilder_table_row input[type='checkbox'],.htproelement select").removeAttr("disabled");
                    });
                } )( jQuery );
            </script>
        <?php
        echo ob_get_clean();
    }

    // General tab
    function html_general_tabs(){
        ob_start();
        ?>
            <div class="htbuilder-general-tabs">

                <div class="htbuilder-document-section">
                    <div class="htbuilder-column">
                        <a href="https://hasthemes.com/blog-category/ht-builder/" target="_blank">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>/includes/admin/assets/images/video-tutorial.jpg" alt="<?php esc_attr_e( 'Video Tutorial', 'ht-builder-pro' ); ?>">
                        </a>
                    </div>
                    <div class="htbuilder-column">
                        <a href="https://hasthemes.com/blog-category/ht-builder/" target="_blank">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>/includes/admin/assets/images/online-documentation.jpg" alt="<?php esc_attr_e( 'Online Documentation', 'ht-builder-pro' ); ?>">
                        </a>
                    </div>
                    <div class="htbuilder-column">
                        <a href="https://hasthemes.com/contact-us/" target="_blank">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>/includes/admin/assets/images/genral-contact-us.jpg" alt="<?php esc_attr_e( 'Contact Us', 'ht-builder-pro' ); ?>">
                        </a>
                    </div>
                </div>

            </div>
        <?php
        echo ob_get_clean();
    }

    // Element Toogle Button
    function html_element_toogle_button(){
        ob_start();
        ?>
            <span class="open-element-toggle"><?php esc_html_e( 'Toggle All', 'ht-builder-pro' );?></span>
            <script type="text/javascript">
                (function($){
                    $(function() {
                        $('.open-element-toggle').on('click', function() {
                            var inputCheckbox = $('#htbuilder_element_tabs').find('.htbuilder_table_row input[type="checkbox"]');
                            if(inputCheckbox.prop("checked") === true){
                                inputCheckbox.prop('checked', false )
                            } else {
                                inputCheckbox.prop('checked', true )
                            }
                        });
                    });
                } )( jQuery );
            </script>
        <?php
        echo ob_get_clean();
    }

    // Template Tabs
    function html_template_library_tabs(){
        ob_start();
        ?>
        <div class="htoptions-plugins-laibrary">
            <h3><?php echo esc_html__( 'Elementor Template Library', 'ht-builder-pro' ); ?></h3>
            <p><?php echo esc_html__( 'Use Our Ready made Elementor templates and build your blog page and single blog page easily.', 'ht-builder-pro' ); ?></p>
            <div class="htoptions-plugins-area">
                <div class="htoptions-plugins-row">

                    <div class="htoptions-single-plugins"><img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/layout/blog_layout_1.png" alt="">
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'Blog Layout One', 'ht-builder-pro' ); ?></h3>
                            <a href="#" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Preview', 'ht-builder-pro' ); ?></a>
                            <a href="https://freethemescloud.com/download/ht-builder-blog-layout-one/" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Download', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins"><img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/layout/blog_layout_2.png" alt="">
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'Blog Layout Two', 'ht-builder-pro' ); ?></h3>
                            <a href="#" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Preview', 'ht-builder-pro' ); ?></a>
                            <a href="https://freethemescloud.com/download/ht-builder-blog-layout-two/" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Download', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins"><img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/layout/blog_detail_layout_1.png" alt="">
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'Blog Details Layout One', 'ht-builder-pro' ); ?></h3>
                            <a href="#" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Preview', 'ht-builder-pro' ); ?></a>
                            <a href="https://freethemescloud.com/download/ht-builder-blog-details-layout-one/" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Download', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                </div>
            </div>

        </div>
        <?php
        echo ob_get_clean();
    }

    // Plugins Library
    function html_our_plugins_library_tabs() {
        ob_start();
        ?>
        <div class="htoptions-plugins-laibrary">
            <p><?php echo esc_html__( 'Use Our plugins.', 'ht-builder-pro' ); ?></p>
            <div class="htoptions-plugins-area">
                <h3><?php esc_html_e( 'Premium Plugins', 'ht-builder-pro' ); ?></h3>
                <div class="htoptions-plugins-row">
                    
                    <div class="htoptions-single-plugins"><img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/preview_woolentor-pro.jpg" alt="">
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'WooLentor - WooCommerce Page Builder and WooCommerce Elementor Addon', 'ht-builder-pro' ); ?></h3>
                            <a href="http://demo.wphash.com/woolentor/" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Preview', 'ht-builder-pro' ); ?></a>
                            <a href="https://hasthemes.com/plugins/woolentor-pro-woocommerce-page-builder/" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Buy Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>
                    
                    <div class="htoptions-single-plugins"><img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/hasbarpro-preview.jpg" alt="">
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'HashBar Pro - WordPress Notification Bar plugin', 'ht-builder-pro' ); ?></h3>
                            <a href="http://demo.wphash.com/hashbar/" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Preview', 'ht-builder-pro' ); ?></a>
                            <a href="https://hasthemes.com/wordpress-notification-bar-plugin/" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Buy Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>
                    
                    <div class="htoptions-single-plugins"><img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/htscript-preview.png" alt="">
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'HT Script Pro - Insert Header & Footer Code', 'ht-builder-pro' ); ?></h3>
                            <a href="https://hasthemes.com/plugins/insert-headers-and-footers-code-ht-script/" class="htoptions-button" target="_blank"><?php echo esc_html__( 'Buy Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                </div>

                <h3><?php esc_html_e( 'Free Plugins', 'ht-builder-pro' ); ?></h3>
                <div class="htoptions-plugins-row">

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/htmega-addon-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'HT Mega – absolute addons for elementor page builder', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/woolentor-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'WooLentor – WooCommerce elementor addons + builder', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/hashbar-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'Hashbar – WordPress notification bar', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/portfolio-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'HT Portfolio – wordpress portfolio plugin for elementor', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/contactform-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'Contact form 7 widget for elementor page builder', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/htwpbakery-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'HT Mega – absolute addons for wpbakery page builder', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/slider-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'HT slider for elementor', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/instagram-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'WP Instagram – wordpress instagram feed / widget plugin', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/wpmagazine-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'WP News – wordpress news / magazine plugin', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/htteam-member-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'WP Team – wordpress team member plugin', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/wpform-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'WPforms widget for elementor page builder', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/htevent-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'HT Event – wordpress event manager plugin for elementor', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/politic-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'HT Politic – political wordpress plugin', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/htservice-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'HT Service – roofing service wordpress plugin', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/education-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'WP education – education wordpress plugin for elementor', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/film-studio-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'WP Film studio – wordpress movie maker/production plugin', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                    <div class="htoptions-single-plugins htfree-plugins">
                        <div class="htoptions-img">
                            <img src="<?php echo HTBUILDER_PL_URL; ?>includes/admin/assets/images/insurance-icon.png" alt="">
                        </div>
                        <div class="htoptions-plugins-content">
                            <h3><?php echo esc_html__( 'WP Insurance – WordPress Insurance Service Plugin', 'ht-builder-pro' ); ?></h3>
                            <a class="htoptions-button" href="<?php echo esc_url( admin_url() ); ?>plugin-install.php" target="_blank"><?php echo esc_html__( 'Install Now', 'ht-builder-pro' ); ?></a>
                        </div>
                    </div>

                </div>

            </div>
        </div>
        <?php
        echo ob_get_clean();
    }
    

}

new HTBuilder_Admin_Settings_Pro();