<?php

namespace HT_Builder_Pro\Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Base {

    private static $_instance = null;
    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function __construct() {
        add_action( 'init', [ $this, 'i18n' ] );
        add_action( 'plugins_loaded', [ $this, 'init' ] );
        add_action( 'admin_init', [ $this, 'check_plugin_active' ] );
    }

    /*
    * Load Text Domain
    */
    public function i18n() {
        load_plugin_textdomain( 'ht-builder-pro' );
    }

    /*
    * Check if HT Builder installed and activated
    */
    public function check_plugin_active(){
        if ( ! is_plugin_active( 'ht-builder/ht-builder.php' ) ) {
            add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
            return;
        }
    }

    /*
    * Init Hook in Init
    */
    public function init() {

        // Include File
        $this->require_include_files();

        // Register custom category
        add_action( 'elementor/elements/categories_registered', [ $this, 'add_category' ] );

    }

    /*
    * Include File
    */
    public function require_include_files(){
        if ( ! function_exists('is_plugin_active') ){ include_once( ABSPATH . 'wp-admin/includes/plugin.php' ); }
        require( __DIR__ . '/helper-function.php');
        if( htbuilder_get_option_pro( 'enablecustomtemplate', 'htbuilder_templatebuilder_tabs', 'on' ) == 'on' ){
            require(  __DIR__ .'/../classes/class.template_builder.php' );
            require(  __DIR__ .'/../classes/class.custom-metabox.php' );
            require(  __DIR__ .'/../classes/class.widgets_control.php' );
        }
    }

    /**
     * Add custom category.
     *
     * @param $elements_manager
     */
    public function add_category( $elements_manager ) {
        $elements_manager->add_category(
            'ht_builder_pro',
            [
                'title' => __( 'HT Builder Pro', 'ht-builder' ),
                'icon' => 'fa fa-snowflake-o',
            ]
        );
    }

    /**
     * Admin notice.
     * Doesn't have Elementor installed or activated.
     */
    public function admin_notice_missing_main_plugin() {

        if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

        $htbuilder = 'ht-builder/ht-builder.php';
        if( $this->is_plugins_active( $htbuilder ) ) {
            if( ! current_user_can( 'activate_plugins' ) ) {
                return;
            }
            $activation_url = wp_nonce_url( 'plugins.php?action=activate&amp;plugin=' . $htbuilder . '&amp;plugin_status=all&amp;paged=1&amp;s', 'activate-plugin_' . $htbuilder );
            $button_text = '<p><a href="' . $activation_url . '" class="button-primary">' . __( 'Activate', 'ht-builder' ) . '</a></p>';
        } else {
            if( ! current_user_can( 'activate_plugins' ) ) {
                return;
            }
            $activation_url = wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=ht-builder' ), 'install-plugin_ht-builder' );
            $button_text = '<p><a href="' . $activation_url . '" class="button-primary">' . __( 'Install', 'ht-builder' ) . '</a></p>';
        }

        $message = sprintf(
            /* translators: 1: Plugin name 2: HT Builder */
            esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'ht-builder' ),
            '<strong>' . esc_html__( 'HT Builder Pro', 'ht-builder' ) . '</strong>',
            '<strong>' . esc_html__( 'HT Builder', 'ht-builder' ) . '</strong>'
        );
        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p>%2$s</div>', $message, $button_text );

    }

    /*
    * Check Plugins is Installed or not
    */
    public function is_plugins_active( $pl_file_path = NULL ){
        $installed_plugins_list = get_plugins();
        return isset( $installed_plugins_list[$pl_file_path] );
    }


}
Base::instance();